#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jul 18 16:17:25 2023

@author: salguod
"""

# Campo de velocidade e Linha de Corrente

import matplotlib.pyplot as plt
import numpy as np

# Define o numero de pontos do campo de velocidades

X,Y = np.meshgrid(np.linspace(-5,5,10),np.linspace(-5,5,10))

# Calcula as componentes do campo de velocidades 

u = (X**2) #Componente na direção x - mudar aqui!
v = (X*Y*Y*Y)
m=np.sqrt(u**2+v**2) #Componente na direção y - mudar aqui!

col=zip(X,Y,u,v)

# Cria os gráficos

fig, ax = plt.subplots(figsize=(12,12))
plt.tick_params(axis='both', which='major', labelsize=30)

# Cria as linhas de corrente 

ax.streamplot(X, Y, u, v, density=[0.8, 5], color="green", )

# Cria o campo de velocidade 

ax.quiver(X,Y,u/m,v/m,scale=20)

ax.plot(X, Y,'o',markersize=5)

#Cria um arquivo de dados na pasta do programa

file1 = open("Arquivo de Dados.txt", "w")
file1.write('           x(m)                      Y(m)                   u(m/s)                    v(m/s)   \n')
for i in col:
    np.savetxt(file1, np.c_[i])
file1.close() #Close the file when we’re done!

#Decoração do gráfico
      
ax.xaxis.grid(True, color ="black")
ax.yaxis.grid(True, color ="black")
ax.xaxis.label.set_size(30)
ax.yaxis.label.set_size(30)
#Modifica o título do gráfico
 
ax.set_title(r'Campo de Velocidade e Linhas de Corrente ',color='black', fontdict={'fontsize': 34, 'fontweight': 'medium'})
ax.set_xlabel('$X$')
ax.set_ylabel('$Y$')
ax.xaxis.label.set_size(30)
ax.yaxis.label.set_size(30)

#Grava o gráfico em formato png na pasta do programa.

fig.savefig('figura.png')

plt.show()
